@@ -17,7 +17,7 @@ from hagworm.extend.base import Utils
 from hagworm.extend.logging import LogFileRotator
 
 from setting import ConfigDynamic
-from service.base import DataSource
+from service import DataSource
 from controller import router
 
 
