@@ -90,7 +90,7 @@ class SubProcess(TaskInterface):
     @classmethod
     async def create(cls, program, *args, stdin=None, stdout=None, stderr=None, **kwargs):
 
-        inst = cls(program, *args, stdin, stdout, stderr, **kwargs)
+        inst = cls(program, *args, stdin=stdin, stdout=stdout, stderr=stderr, **kwargs)
         await inst.start()
 
         return inst
