@@ -21,6 +21,11 @@ class Graph:
 
         return f'<DiGraph: {self.name}, vertices: {self._graph.vcount()}, edges: {self._graph.ecount()}>'
 
+    @property
+    def vertices(self) -> Dict[str, Vertex]:
+
+        return self._vertices
+
     @property
     def name(self) -> str:
 
@@ -43,7 +48,7 @@ class Graph:
 
     def clear(self):
 
-        self._graph.delete_vertices()
+        self._graph.clear()
         self._vertices.clear()
 
     def find_vertex(self, name: str) -> Vertex:
@@ -67,27 +72,28 @@ class Graph:
 
         self._graph.add_edges(edges)
 
-    def find_edges(self, source: Vertex, target: Vertex) -> List[Edge]:
+    def get_edge(self, source: Vertex, target: Vertex) -> Edge:
 
-        edges = self._graph.es.select(_source=source.index, _target=target.index).indices
+        eid = self._graph.get_eid(source[r'name'], target[r'name'], error=False)
 
-        return [self._graph.es[_e] for _e in edges]
+        if eid < 0:
+            return None
 
-    def add_edge(self, source: Vertex, target: Vertex) -> Edge:
+        return self._graph.es[eid]
 
-        edges = self.find_edges(source, target)
+    def add_edge(self, source: Vertex, target: Vertex):
 
-        if edges:
-            return edges[0]
-        else:
-            return self._graph.add_edge(source, target)
+        eid = self._graph.get_eid(source[r'name'], target[r'name'], error=False)
+
+        if eid < 0:
+            self._graph.add_edges([(source, target)])
 
     def del_edge(self, source: Vertex, target: Vertex):
 
-        edges = self._graph.es.select(_source=source.index, _target=target.index).indices
+        eid = self._graph.get_eid(source[r'name'], target[r'name'], error=False)
 
-        if edges:
-            self._graph.delete_edges(edges)
+        if eid >= 0:
+            self._graph.delete_edges(eid)
 
     def del_vertex_edge(self, name: str, mode=r'all'):
 
