@@ -62,6 +62,14 @@ class Enum(_Enum):
         return value in cls.to_values_dict()
 
 
+class IntEnum(int, _Enum):
+    pass
+
+
+class StrEnum(str, _Enum):
+    pass
+
+
 class Result(dict):
     """返回结果类
     """
